Webservice class

Constructors

Webservice()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

postRequest({dynamic uri, dynamic baseUrl, dynamic body, dynamic header, dynamic jsonEncoded = true, bool hasBearer = false, dynamic onSuccess(dynamic responseBody)?, dynamic onFailure(dynamic error)?, Function? onTimeout, dynamic onConnectionFailed(dynamic connectionFailed)?, dynamic context}) → dynamic
uploadImage({required dynamic uri, required File file, dynamic body, required String? fileType, dynamic header, bool hasBearer = false, required Function onSuccess, Function? onFailure, Function? onTimeout, Function? onConnectionFailed}) → dynamic