Global class

Constructors

Global()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

addMember → const String
baseApiUrl → const String
baseUrl → const String
blockUser → const String
createGroup → const String
createUser → const String
getUserDetails → const String
removeMember → const String
updateFCMToken → const String
updateProfile → const String
updateUserRole → const String
uploadFileNew → const String
userList → const String