SessionKeys class

Constructors

SessionKeys()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

chatFcmToken ↔ String
getter/setter pair
chatUserEmail ↔ String
getter/setter pair
chatUserFirstName ↔ String
getter/setter pair
chatUserId ↔ String
getter/setter pair
chatUserLastName ↔ String
getter/setter pair
chatUserMobile ↔ String
getter/setter pair
chatUserName ↔ String
getter/setter pair
chatUserProfilePic ↔ String
getter/setter pair
chatUserRole ↔ String
getter/setter pair
secKey ↔ String
getter/setter pair