CustomTextStyles class

Constructors

CustomTextStyles()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bold({required dynamic fontSize, required dynamic fontColor}) → dynamic
medium({required dynamic fontSize, required dynamic fontColor, bool? isUnderLine}) → dynamic
normal({required dynamic fontSize, required dynamic fontColor, bool? isUnderLine}) → dynamic
semiBold({required dynamic fontSize, required dynamic fontColor}) → dynamic