helper/keyboard_avoider library
/ @dart=2.0
Classes
- KeyboardAvoider
-
Wraps the child in a AnimatedContainer that adjusts its bottom
paddingto accommodate the on-screen keyboard. Unlike a Scaffold, it only insets by the actual amount obscured by the keyboard. If autoScroll is true and the child contains a focused widget such as a TextField, automatically scrolls so that it is just visible above the keyboard, plus any additional focusPadding. - KeyboardAvoiderState