GroupData class

Constructors

GroupData({UserPermission? userPermission, String? userName, bool? onlineStatus, String? groupName, bool? isGroup, String? imagePath, String? opponentUserId})
GroupData.fromJson(Map<String, dynamic> json)
factory

Properties

groupName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imagePath String?
getter/setter pair
isGroup bool?
getter/setter pair
onlineStatus bool?
getter/setter pair
opponentUserId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userName String?
getter/setter pair
userPermission UserPermission?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited