Permission class

Constructors

Permission({int? clearChat, int? changeGroupName, int? addMember, int? addProfilePicture, int? deleteMessage, int? removeMember, int? sendMessage, int? exitGroup, int? deleteChat})
Permission.fromJson(Map<String, dynamic> json)
factory

Properties

addMember int?
getter/setter pair
addProfilePicture int?
getter/setter pair
changeGroupName int?
getter/setter pair
clearChat int?
getter/setter pair
deleteChat int?
getter/setter pair
deleteMessage int?
getter/setter pair
exitGroup int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
removeMember int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendMessage int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited