RecentMessage class

Constructors

RecentMessage({CreateAt? timeMilliSeconds, String? replyMsgId, String? type, int? time, String? replyUser, String? replyUserId, CreateAt? sentAt, List<String>? viewBy, String? senderName, String? replyMsg, String? msgId, String? message, String? sentBy, String? replyMsgType})
RecentMessage.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
getter/setter pair
msgId String?
getter/setter pair
replyMsg String?
getter/setter pair
replyMsgId String?
getter/setter pair
replyMsgType String?
getter/setter pair
replyUser String?
getter/setter pair
replyUserId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderName String?
getter/setter pair
sentAt CreateAt?
getter/setter pair
sentBy String?
getter/setter pair
time int?
getter/setter pair
timeMilliSeconds CreateAt?
getter/setter pair
type String?
getter/setter pair
viewBy List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited