GroupListModel class

Constructors

GroupListModel({String? imagePath, String? groupName, LatestTime? latestTime, int? unreadCount, String? msgType, String? recentMsg, bool? isGroup, String? groupId, String? opponentUserId, int? isBlocked})
GroupListModel.fromJson(Map<String, dynamic> json)
factory

Properties

groupId String?
getter/setter pair
groupName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imagePath String?
getter/setter pair
isBlocked int?
getter/setter pair
isGroup bool?
getter/setter pair
latestTime LatestTime?
getter/setter pair
msgType String?
getter/setter pair
opponentUserId String?
getter/setter pair
recentMsg String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unreadCount int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited