ProfileDetailModel class

Constructors

ProfileDetailModel({String? userName, String? firstName, String? lastName, String? name, String? email, String? secretKey, String? profilePicture, String? id, String? userId})
ProfileDetailModel.fromJson(Map<String, dynamic> json)
factory

Properties

email String?
getter/setter pair
firstName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
lastName String?
getter/setter pair
name String?
getter/setter pair
profilePicture String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String?
getter/setter pair
userId String?
getter/setter pair
userName String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited