SetUserRole class

Constructors

SetUserRole({int? deleteMessage, int? sendMessage, int? updateProfile, int? editMessage, int? createGroup, int? createOneToOneChat, int? deleteChat})
SetUserRole.fromJson(Map<String, dynamic> json)
factory

Properties

createGroup int?
getter/setter pair
createOneToOneChat int?
getter/setter pair
deleteChat int?
getter/setter pair
deleteMessage int?
getter/setter pair
editMessage int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendMessage int?
getter/setter pair
updateProfile int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited