ContactListViewState class
- Inheritance
-
- Object
- State<
ContactListView> - ContactListViewState
Constructors
Properties
- addMemberLoader ↔ RxBool
-
getter/setter pair
- connectLoader ↔ RxBool
-
getter/setter pair
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadData ↔ RxBool
-
getter/setter pair
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchCommonBorderStyle ↔ OutlineInputBorder
-
getter/setter pair
- searchController ↔ TextEditingController
-
getter/setter pair
- searchText ↔ String
-
getter/setter pair
-
searchUserList
↔ RxList<
UserList> -
getter/setter pair
-
usersList
↔ RxList<
UserList> -
getter/setter pair
- widget → ContactListView
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
addMemberApi(
{List? otherUserId, BuildContext? contexts}) → dynamic -
appBar(
) → Widget -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
connectUser(
{dynamic otherUserId}) → dynamic -
contactItem(
UserList users) → Widget -
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant ContactListView oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
inherited
-
getUsersApi(
) → dynamic -
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited